@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -17,33 +17,33 @@
 #
 """ Blob codes for storing binary data semi-efficiently.
 
-This module offers means to store and encode binary blobs in C++ semi
+This module offers means to store and encode binary blobs in C semi
 efficiently. The "StreamData" class is used in two places, for constants
 and for freezing of bytecode.
 """
 
-class StreamData:
-    def __init__(self, identifier):
+class StreamData(object):
+    def __init__(self):
         self.stream_data = bytes()
-        self.identifier = identifier
 
     def getStreamDataCode(self, value, fixed_size = False):
+        offset = self.getStreamDataOffset(value)
+
+        if fixed_size:
+            return "&constant_bin[ %d ]" % offset
+        else:
+            return "&constant_bin[ %d ], %d" % (
+                offset,
+                len(value)
+            )
+
+    def getStreamDataOffset(self, value):
         offset = self.stream_data.find(value)
         if offset == -1:
             offset = len(self.stream_data)
             self.stream_data += value
 
-        if fixed_size:
-            return "&%s[ %d ]" % (
-                self.identifier,
-                offset
-            )
-        else:
-            return "&%s[ %d ], %d" % (
-                self.identifier,
-                offset,
-                len(value)
-            )
+        return offset
 
     def getBytes(self):
         return self.stream_data
